package de.jottyfan.timetrack.modules.done;

import java.io.Serializable;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.RequestScoped;
import javax.faces.context.FacesContext;

import de.jottyfan.timetrack.help.Navigation;
import de.jottyfan.timetrack.help.Pages;
import de.jottyfan.timetrack.modules.ControlInterface;

/**
 * 
 * @author henkej
 * 
 */
@ManagedBean
@RequestScoped
public class DoneControl extends Navigation implements ControlInterface, Serializable {
	private static final long serialVersionUID = 1L;

	@ManagedProperty(value = "#{doneModel}")
	private DoneModel model;

	@ManagedProperty(value = "#{facesContext}")
	private FacesContext facesContext;

	public String toStart() {
		return navigateTo(Pages.START);
	}

	public String toList() {
		boolean ready = model.init(facesContext);
		return ready ? navigateTo(Pages.DONE_INIT) : toStart();
	}

	public String toAdd() {
		DoneBean bean = new DoneBean();
		bean.setTimeFrom(getCurrentDate());
		model.setBean(bean);
		boolean ready = model.loadDefaults(facesContext);
		return ready ? navigateTo(Pages.DONE_ADD) : toList();
	}

	public String toEdit(DoneBean bean) {
		model.setBean(bean);
		boolean ready = model.loadDefaults(facesContext);
		return ready ? navigateTo(Pages.DONE_EDIT) : toList();
	}

	public String toDelete(DoneBean bean) {
		model.setBean(bean);
		return navigateTo(Pages.DONE_DELETE);
	}

	public String doUpdate() {
		boolean ready = model.update(facesContext);
		return ready ? toList() : toEdit(model.getBean());
	}

	public String doDelete() {
		boolean ready = model.delete(facesContext);
		return ready ? toList() : toDelete(model.getBean());
	}

	public String doAdd() {
		boolean ready = model.insert(facesContext);
		return ready ? toList() : toAdd();
	}

	public String getCurrentTimeAsString() {
		return new SimpleDateFormat("HH:mm:ss").format(getCurrentDate());
	}

	public Timestamp getCurrentDate() {
		return Timestamp.valueOf(LocalDateTime.now());
	}

	public DoneModel getModel() {
		return model;
	}

	public void setModel(DoneModel model) {
		this.model = model;
	}

	public void setFacesContext(FacesContext facesContext) {
		this.facesContext = facesContext;
	}
}
