package de.jottyfan.timetrack.modules.note;

import java.io.Serializable;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.RequestScoped;
import javax.faces.context.FacesContext;

import de.jottyfan.timetrack.help.Navigation;
import de.jottyfan.timetrack.help.Pages;
import de.jottyfan.timetrack.modules.ControlInterface;
import de.jottyfan.timetrack.modules.Model;

/**
 * 
 * @author henkej
 * 
 */
@ManagedBean
@RequestScoped
public class NoteControl extends Navigation implements ControlInterface, Serializable
{
	private static final long serialVersionUID = 1L;

	@ManagedProperty(value = "#{noteModel}")
	private NoteModel model;

	@ManagedProperty(value = "#{facesContext}")
	private FacesContext facesContext;

	public String toStart()
	{
		return navigateTo(Pages.START);
	}
	
	public String toList()
	{
		boolean ready = model.init(facesContext);
		return ready ? navigateTo(Pages.NOTE_LIST) : "";
	}

	public String toItem(NoteBean bean)
	{
		model.setBean(bean);
		return navigateTo(Pages.NOTE_ITEM);
	}
	
	public String toAdd()
	{
		return toItem(new NoteBean(null));
	}

	public String doAdd()
	{
		boolean ready = model.add(facesContext);
		return ready ? toList() : toItem(model.getBean());
	}

	public String doUpdate()
	{
		boolean ready = model.update(facesContext);
		return ready ? toList() : toItem(model.getBean());
	}

	public String doDelete()
	{
		boolean ready = model.delete(facesContext);
		return ready ? toList() : toItem(model.getBean());
	}
	
	/**
	 * trim s to maxLength; if s > maxLength, append ...
	 * 
	 * @param s
	 * @param maxLength
	 * @return
	 */
	public String trimTo(String s, Integer maxLength)
	{
		if (s == null)
		{
			return s;
		}
		else
		{
			String firstLine = s.contains("\n") ? s.substring(0, s.indexOf("\n")) : s;
			if (firstLine.length() > maxLength)
			{
				return firstLine.substring(0, maxLength).concat("...");
			}
			else if (s.contains("\n"))
			{
				return firstLine.concat("...");
			}
			else
			{
				return firstLine;
			}
		}
	}
	
	public Long getAmount() {
		return model.getAmount(facesContext);
	}

	@Override
	public Model getModel()
	{
		return model;
	}

	public void setModel(NoteModel model)
	{
		this.model = model;
	}

	public void setFacesContext(FacesContext facesContext)
	{
		this.facesContext = facesContext;
	}
}
